/*******************************************************************************
* Copyright (C) 2013 Spansion LLC. All Rights Reserved. 
*
* This software is owned and published by: 
* Spansion LLC, 915 DeGuigne Dr. Sunnyvale, CA  94088-3453 ("Spansion").
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND 
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with Spansion 
* components. This software is licensed by Spansion to be adapted only 
* for use in systems utilizing Spansion components. Spansion shall not be 
* responsible for misuse or illegal use of this software for devices not 
* supported herein.  Spansion is providing this software "AS IS" and will 
* not be responsible for issues arising from incorrect user implementation 
* of the software.  
*
* SPANSION MAKES NO WARRANTY, EXPRESS OR IMPLIED, ARISING BY LAW OR OTHERWISE,
* REGARDING THE SOFTWARE (INCLUDING ANY ACOOMPANYING WRITTEN MATERIALS), 
* ITS PERFORMANCE OR SUITABILITY FOR YOUR INTENDED USE, INCLUDING, 
* WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, THE IMPLIED 
* WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE OR USE, AND THE IMPLIED 
* WARRANTY OF NONINFRINGEMENT.  
* SPANSION SHALL HAVE NO LIABILITY (WHETHER IN CONTRACT, WARRANTY, TORT, 
* NEGLIGENCE OR OTHERWISE) FOR ANY DAMAGES WHATSOEVER (INCLUDING, WITHOUT 
* LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS INTERRUPTION, 
* LOSS OF BUSINESS INFORMATION, OR OTHER PECUNIARY LOSS) ARISING FROM USE OR 
* INABILITY TO USE THE SOFTWARE, INCLUDING, WITHOUT LIMITATION, ANY DIRECT, 
* INDIRECT, INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES OR LOSS OF DATA, 
* SAVINGS OR PROFITS, 
* EVEN IF SPANSION HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. 
* YOU ASSUME ALL RESPONSIBILITIES FOR SELECTION OF THE SOFTWARE TO ACHIEVE YOUR
* INTENDED RESULTS, AND FOR THE INSTALLATION OF, USE OF, AND RESULTS OBTAINED 
* FROM, THE SOFTWARE.  
*
* This software may be replicated in part or whole for the licensed use, 
* with the restriction that this Disclaimer and Copyright notice must be 
* included with each copy of this software, whether used in part or whole, 
* at all times.  
*/

/******************************************************************************/
/** \file main.c
 **
 ** Main Module
 **
 ** This example switches the RGB LEDs on an off by pressing the push button
 ** SW2 of the SK-FM4-U120-MB9560 board.
 **
 ** History:
 **   - 2013-03-21  1.0  MWi        First version.
 **
 ******************************************************************************/

/******************************************************************************/
/* Include files                                                              */
/******************************************************************************/
#include "mcu.h"
 
/**
 ******************************************************************************
 ** \brief  GPIO init function
 **
 ** This function uses bit field access to the ports via load store.
 ******************************************************************************/
static void InitGpio(void)
{
  FM4_GPIO->DDR6_f.P68 = 0u;     // Port 68 (SW2) to input
  
  FM4_GPIO->PDOR2_f.P27 = 1u;    // LED R off (for default)
  FM4_GPIO->PDOR3_f.P38 = 1u;    // LED G off (for default)
  FM4_GPIO->PDORE_f.PE0 = 1u;    // LED B off (for default)
  
  FM4_GPIO->DDR2_f.P27 = 1u;     // LED R to output
  FM4_GPIO->DDR3_f.P38 = 1u;     // LED G to output
  FM4_GPIO->DDRE_f.PE0 = 1u;     // LED B to output  
}

/**
 ******************************************************************************
 ** \brief  Main function of project for MB9B560R series.
 **
 ** This function uses bit band alias access to the ports.
 **
 ** \return uint32_t return value, if needed
 ******************************************************************************/
int32_t main(void) 
{
static  uint8_t u8LedState = 0u;
  
  InitGpio();
  
  while(1u)
  {
    if (0u == bFM4_GPIO_PDIR6_P68)     // SW2 pressed?
    {
      u8LedState++;
      
      if (u8LedState > 7u)
      {
        u8LedState = 0u;
      }
      
      switch(u8LedState)
      {
        case 0u:
          bFM4_GPIO_PDOR2_P27 = 1u;    // LED R off 
          bFM4_GPIO_PDOR3_P38 = 1u;    // LED G off
          bFM4_GPIO_PDORE_PE0 = 1u;    // LED B off
          break;
        case 1u:
          bFM4_GPIO_PDOR2_P27 = 0u;    // LED R on 
          bFM4_GPIO_PDOR3_P38 = 1u;    // LED G off
          bFM4_GPIO_PDORE_PE0 = 1u;    // LED B off
          break;
        case 2u:
          bFM4_GPIO_PDOR2_P27 = 1u;    // LED R off 
          bFM4_GPIO_PDOR3_P38 = 0u;    // LED G on
          bFM4_GPIO_PDORE_PE0 = 1u;    // LED B off
          break;
        case 3u:
          bFM4_GPIO_PDOR2_P27 = 1u;    // LED R off 
          bFM4_GPIO_PDOR3_P38 = 1u;    // LED G off
          bFM4_GPIO_PDORE_PE0 = 0u;    // LED B on
          break;
        case 4u:
          bFM4_GPIO_PDOR2_P27 = 0u;    // LED R on 
          bFM4_GPIO_PDOR3_P38 = 0u;    // LED G on
          bFM4_GPIO_PDORE_PE0 = 1u;    // LED B off
          break;
        case 5u:
          bFM4_GPIO_PDOR2_P27 = 1u;    // LED R off 
          bFM4_GPIO_PDOR3_P38 = 0u;    // LED G on
          bFM4_GPIO_PDORE_PE0 = 0u;    // LED B on
          break;
        case 6u:
          bFM4_GPIO_PDOR2_P27 = 0u;    // LED R on 
          bFM4_GPIO_PDOR3_P38 = 1u;    // LED G off
          bFM4_GPIO_PDORE_PE0 = 0u;    // LED B on
          break;
        case 7u:
          bFM4_GPIO_PDOR2_P27 = 0u;    // LED R on 
          bFM4_GPIO_PDOR3_P38 = 0u;    // LED G on
          bFM4_GPIO_PDORE_PE0 = 0u;    // LED B on
          break;
        default:
          break;
      }
      
      while(0u == bFM4_GPIO_PDIR6_P68) // Wait for SW2 release
      {}
    }
  }
}
