/*******************************************************************************
* Copyright (C) 2014 Spansion LLC. All Rights Reserved.
*
* This software is owned and published by:
* Spansion LLC, 915 DeGuigne Dr. Sunnyvale, CA  94088-3453 ("Spansion").
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with Spansion
* components. This software is licensed by Spansion to be adapted only
* for use in systems utilizing Spansion components. Spansion shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein.  Spansion is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* SPANSION MAKES NO WARRANTY, EXPRESS OR IMPLIED, ARISING BY LAW OR OTHERWISE,
* REGARDING THE SOFTWARE (INCLUDING ANY ACOOMPANYING WRITTEN MATERIALS),
* ITS PERFORMANCE OR SUITABILITY FOR YOUR INTENDED USE, INCLUDING,
* WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, THE IMPLIED
* WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE OR USE, AND THE IMPLIED
* WARRANTY OF NONINFRINGEMENT.
* SPANSION SHALL HAVE NO LIABILITY (WHETHER IN CONTRACT, WARRANTY, TORT,
* NEGLIGENCE OR OTHERWISE) FOR ANY DAMAGES WHATSOEVER (INCLUDING, WITHOUT
* LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS INTERRUPTION,
* LOSS OF BUSINESS INFORMATION, OR OTHER PECUNIARY LOSS) ARISING FROM USE OR
* INABILITY TO USE THE SOFTWARE, INCLUDING, WITHOUT LIMITATION, ANY DIRECT,
* INDIRECT, INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES OR LOSS OF DATA,
* SAVINGS OR PROFITS,
* EVEN IF SPANSION HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* YOU ASSUME ALL RESPONSIBILITIES FOR SELECTION OF THE SOFTWARE TO ACHIEVE YOUR
* INTENDED RESULTS, AND FOR THE INSTALLATION OF, USE OF, AND RESULTS OBTAINED
* FROM, THE SOFTWARE.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/******************************************************************************/
/** \file i2clcd.h
 **
 ** This file contains the definitions and function prototypes required to 
 ** initialize the I2C bus and LCD interface
 **
 ** History:
 **   - 2014-09-18  1.0  Deepak Naik  First version.
 **
 ******************************************************************************/

#ifndef __I2CLCD_H__
#define __I2CLCD_H__

/******************************************************************************/
/* Include files                                                              */
/******************************************************************************/
#include "base_types.h"
#include "mcu.h"


/******************************************************************************/
/* Global pre-processor symbols/macros ('#define')                            */
/******************************************************************************/

#define I2C_RW_WRITE          (0u)

#define I2C_TIME_OUT          (5000u)    // error counter time-out

#define I2C_STOP_TIMEOUT      (0xFFFFu)  // time-out for stop condition


/******************************************************************************
 * Global type definitions
 ******************************************************************************/

/******************************************************************************/
/* Global variable definitions ('extern')                                     */
/******************************************************************************/

/******************************************************************************/
/* Global function prototypes (definition in C source)                        */
/******************************************************************************/

en_result_t I2cLcd_Init(void);

en_result_t I2cLcd_SetBG(uint16_t u16LcdBrightness);

en_result_t I2cLcd_Write(uint8_t u8Line, char * pcText);

en_result_t I2cLcd_Clear(void);

en_result_t I2cLcd_ReturnHome(void);

int32_t I2cLcd_I2cSendByte(uint8_t u8Data);

int32_t I2cLcd_I2cStart(uint8_t u8Data);

int32_t I2cLcd_I2cWriteStop(void);

int32_t I2cLcd_I2cReadStop(void);

boolean_t I2c_Init(void);

void I2cBusClear(volatile uint32_t* pu32DDR, volatile uint32_t* pu32PFR, volatile uint32_t* pu32PDOR, volatile uint32_t* pu32PDIR, uint32_t u32SclMask, uint32_t u32SdaMask);

#endif /* __LCD_H__ */
/******************************************************************************/
/* EOF (not truncated)                                                        */
/******************************************************************************/

